@@ -2,24 +2,24 @@ import numpy as np
 from . import ffmpeg, utils, configure
 
 
-def read(input_url, stream_id=0, **options):
-    """read image/video frame snapshot
+def read(url, stream_id=0, **options):
+    """Read an image file or a snapshot of a video frame
 
-    :param filename: image/video file
-    :type filename: str
-    :param time: time marker to take a snapshot if `filename` is a video, defaults to None or to take
-                 snapshot at time 0.0.
-    :type time: float, optional
-    :param pix_fmt: returning pixel format, defaults to None
-    :type pix_fmt: str, optional
-    :param background_color: background color if alpha channel is removed, defaults to "white"
-    :type background_color: str, optional
+    :param url: URL of the image or video file to read.
+    :type url: str
+    :param stream_id: video stream id (numeric part of ``v:#`` specifier), defaults to 0.
+    :type stream_id: int, optional
+    :param \\**options: other keyword options (see :doc:`options`)
+    :type \\**options: dict, optional
     :return: image data
     :rtype: numpy.ndarray
+
+    Note on \\**options: To specify the video frame capture time, use `time`
+    option which is an alias of `start` standard option.
     """
 
     args = configure.input_timing(
-        input_url,
+        url,
         vstream_id=stream_id,
         aliases={"time": "start"},
         excludes=("start", "end", "duration"),
@@ -29,7 +29,7 @@ def read(input_url, stream_id=0, **options):
     configure.audio_codec("-", args, codec="none")
 
     args, reader_cfg = configure.video_io(
-        input_url,
+        url,
         stream_id,
         output_url="-",
         format="rawvideo",
@@ -45,7 +45,15 @@ def read(input_url, stream_id=0, **options):
 
 
 def write(url, data, **options):
+    """Write a NumPy array to an image file.
 
+    :param url: URL of the image file to write.
+    :type url: str
+    :param data: image data 3-D array (rowsxcolsxcomponents)
+    :type data: `numpy.ndarray`
+    :param \\**options: other keyword options (see :doc:`options`)
+    :type \\**options: dict, optional
+    """
     args = configure.input_timing(
         "-", vstream_id=0, excludes=("start", "end", "duration"), **options
     )
