@@ -2,16 +2,21 @@ import numpy as np
 from . import ffmpeg, utils, configure
 
 
-def read(url, vframes, stream_id=0, **options):
-    """read video frames
+def read(url, vframes=None, stream_id=0, **options):
+    """Read video frames
+
+    :param url: URL of the video file to read.
+    :type url: str
+    :param vframes: number of frames to read, default to None. If not set,
+                    uses the timing options to determine the number of frames.
+    :type vframes: int, optional
+    :param stream_id: video stream id (numeric part of ``v:#`` specifier), defaults to 0.
+    :type stream_id: int, optional
+    :param \\**options: other keyword options (see :doc:`options`)
+    :type \\**options: dict, optional
 
-    :param filename: audio/video filename
-    :type filename: str
-    :param vframes: number of frames to read
-    :type vframes: [type]
-    :raises Exception: if FFmpeg fails
     :return: frame rate and video frame data (dims: time x rows x cols x pix_comps)
-    :rtype: (fractions.Fraction, numpy.ndarray)
+    :rtype: (`fractions.Fraction`, `numpy.ndarray`)
     """
 
     args = configure.input_timing(url, vstream_id=stream_id, **options)
@@ -33,7 +38,17 @@ def read(url, vframes, stream_id=0, **options):
 
 
 def write(url, rate, data, **options):
+    """Write Numpy array to a video file
 
+    :param url: URL of the video file to write.
+    :type url: str
+    :param rate: frame rate in frames/second
+    :type rate: `float`, `int`, or `fractions.Fraction`
+    :param data: video frame data 4-D array (framexrowsxcolsxcomponents)
+    :type data: `numpy.ndarray`
+    :param \\**options: other keyword options (see :doc:`options`)
+    :type \\**options: dict, optional
+    """
     args = configure.input_timing(
         "-",
         vstream_id=0,
